==> links_v0.7.0b.tar.gz: links/system/counter.class.php <==
<?php
///////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                         Class for counter Ver1.24
//                    Copyright (C) 2003  WHITEWING 
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///////////////////////////////////////////////////////////////////////////

class counter{
 var $count;
 var $ip;

 function counter($file_path,$figure="5",$ip_mode="1",$mode="1"){
  $this->read_ct($file_path);
   if((($this->ip!=$_SERVER["REMOTE_ADDR"]) or !$ip_mode) and $mode){
    $this->count++;
    $this->write_ct($file_path,$this->count);
    }
  $this->count = sprintf("%0".$figure."d", $this->count);
  return $this->count;
 }

 function read_ct($file_path){
  $fp=@fopen($file_path,"r");
  if($fp){
   flock($fp,LOCK_SH);
   $buf=fread($fp,filesize($file_path));
   flock($fp,LOCK_UN);
   fclose($fp);
   $this->count=strtok($buf,"\n");
   $this->ip=strtok("\n");
  }
 return ;
 }

 function write_ct($file_path,$count){
  $fl=$count."\n".$_SERVER["REMOTE_ADDR"]."\n";
  $fp=@fopen($file_path,"w");
  if($fp){
   flock($fp,LOCK_EX);
   fwrite($fp,$fl);
   flock($fp,LOCK_UN);
   fclose($fp);
  }
 return ;
 }
}

class img_counter extends counter {
 var $tag;
 function img_counter($file_path,$img_dir,$extension,$figure="5",$ip_mode="1",$mode="1"){
  $this->counter($file_path,$figure,$ip_mode,$mode);
  $count=$this->count;
  $i=-1;
  do{
   $i++;
   $gf[$i]= $count % 10;
   $count /= 10;
  }while($count >= 1);
   $this->tag=NULL;
   for($j=$i;$j<$figure - 1;$j++){
    $this->tag.= ('<img src="'.$img_dir.'0'.$extension.'" alt="0" />');
   }
  while($i>=0){
  $this->tag .= ('<img src="'.$img_dir.$gf[$i].$extension.'" alt="'.$gf[$i].'" />');
  $i--;
  }
 return $this->tag;
 }
}

?>

==> links_v0.7.3a.tar.gz: links/system/counter.class.php <==
<?php
///////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                         Class for counter Ver1.25
//                    Copyright (C) 2003  WHITEWING 
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///////////////////////////////////////////////////////////////////////////

class counter{
 var $count;
 var $ip;

 function counter($file_path,$figure="5",$ip_mode="1",$mode="1"){
  $this->read_ct($file_path);
   if((($this->ip!=$_SERVER["REMOTE_ADDR"]) or !$ip_mode) and $mode){
    $this->count++;
    $this->write_ct($file_path);
    }
  $this->count = sprintf("%0".$figure."d", $this->count);
  return $this->count;
 }

 function read_ct($file_path){
  if($fp=@fopen($file_path,"r")){
   flock($fp,LOCK_SH);
   $buf=fread($fp,filesize($file_path));
   flock($fp,LOCK_UN);
   fclose($fp);
   $this->count=strtok($buf,"\n");
   $this->ip=strtok("\n");
  }
 return ;
 }

 function write_ct($file_path){
  $fl=$this->count."\n".$_SERVER["REMOTE_ADDR"]."\n";
  if($fp=@fopen($file_path,"w")){
   flock($fp,LOCK_EX);
   fwrite($fp,$fl);
   flock($fp,LOCK_UN);
   fclose($fp);
  }
 return ;
 }
}

class img_counter extends counter {
 var $tag;
 function img_counter($file_path,$img_dir,$extension,$figure="5",$ip_mode="1",$mode="1"){
  $this->counter($file_path,$figure,$ip_mode,$mode);
  $count=$this->count;
  $i=-1;
  do{
   $i++;
   $gf[$i]= $count % 10;
   $count /= 10;
  }while($count >= 1);
   $this->tag=NULL;
   for($j=$i;$j<$figure - 1;$j++){
   	$size=getimagesize($img_dir."0".$extension);
    $this->tag.= ('<img src="'.$img_dir.'0'.$extension.'" alt="0" '.$size[3].' />');
   }
  while($i>=0){
  $size=getimagesize($img_dir."0".$extension);
  $this->tag .= ('<img src="'.$img_dir.$gf[$i].$extension.'" alt="'.$gf[$i].'" '.$size[3].' />');
  $i--;
  }
 return $this->tag;
 }
}

?>
